Nxpy Core
=========

You can install the library with pip::

    pip install nxpy-core

*Nxpy Core* contains generic implementation components on which other libraries depend. It is not
meant for standalone use. 

The library's documentation is available on
`ReadTheDocs <https://nxpy.readthedocs.io/en/latest/core.html>`_.
